@@ -149,3 +149,10 @@ class ConfigService:
             return self.get_property('download_category_path')
         except ValueError:
             return True
+
+    def get_check_course_category(self) -> bool:
+        # returns a stored boolean if category should be downloaded
+        try:
+            return self.get_property('check_course_category')
+        except ValueError:
+            return True
