@@ -25,8 +25,8 @@ from requests.exceptions import InvalidSchema, InvalidURL, MissingSchema
 from youtube_dl.utils import format_bytes, timeconvert
 from moodlerpd.state.course import File
 from moodlerpd.state.course import Course
-from moodlerpd.utils.path_tools import PathTools
 from moodlerpd.client.request_client import RequestClient
+from moodlerpd.utils.path_tools import PathTools
 
 
 class URLTarget(object):
@@ -60,8 +60,8 @@ class URLTarget(object):
         self.verify_cert = not skip_cert_verify
         self.options = options
 
-        # get valid filename
-        self.filename = PathTools.to_valid_name(self.file.content_filename)
+        # get filename
+        self.filename = self.file.content_filename
 
         # To return errors
         self.success = False
@@ -153,12 +153,12 @@ class URLTarget(object):
         self.fs_lock.acquire()
         new_path = self._get_path_of_non_existent_file(path)
 
-        logging.debug('T%s - Seting up target file: "%s"', self.thread_id, new_path)
+        logging.debug('T%s - Setting up target file: "%s"', self.thread_id, new_path)
         try:
             open(new_path, 'a').close()
         except Exception as e:
             self.fs_lock.release()
-            logging.error('T%s - Failed seting up target file: "%s"', self.thread_id, new_path)
+            logging.error('T%s - Failed setting up target file: "%s"', self.thread_id, new_path)
             raise e
 
         self.fs_lock.release()
@@ -425,8 +425,7 @@ class URLTarget(object):
             url_to_download,
             self.file.saved_to,
             context=self.ssl_context,
-            reporthook=self.add_progress,
-            cookies_path=cookies_path,
+            reporthook=self.add_progress
         )
 
         self.set_utime(last_modified)
@@ -497,21 +496,24 @@ class URLTarget(object):
         Args:
             ignore_attributes (bool, optional): If the file attributes should be ignored. Defaults to False.
         """
+        file_name, file_extension = os.path.splitext(self.filename)
+
+        valid_filename = PathTools.to_valid_name(file_name)
 
         if self.file.content_type == 'description' and not ignore_attributes:
-            self.file.saved_to = str(Path(self.destination) / (self.filename + '.md'))
+            self.file.saved_to = str(Path(self.destination) / (valid_filename + '.md'))
 
             self.file.saved_to = self._rename_if_exists(self.file.saved_to)
 
         elif self.file.module_modname.startswith('url') and not ignore_attributes:
-            self.file.saved_to = str(Path(self.destination) / (self.filename + '.desktop'))
+            self.file.saved_to = str(Path(self.destination) / (valid_filename + '.desktop'))
             if os.name == 'nt' or platform.system() == "Darwin":
-                self.file.saved_to = str(Path(self.destination) / (self.filename + '.URL'))
+                self.file.saved_to = str(Path(self.destination) / (valid_filename + '.URL'))
 
             self.file.saved_to = self._rename_if_exists(self.file.saved_to)
 
         else:  # normal path
-            self.file.saved_to = str(Path(self.destination) / self.filename)
+            self.file.saved_to = str(Path(self.destination) / (valid_filename + file_extension))
 
             self.file.saved_to = self._rename_if_exists(self.file.saved_to)
 
@@ -649,14 +651,11 @@ class URLTarget(object):
             if add_token:
                 url_to_download = self._add_token_to_url(self.file.content_fileurl)
 
-            cookies_path = self.options.get('cookies_path', None)
-
             self.urlretrieve(
                 url_to_download,
                 self.file.saved_to,
                 context=self.ssl_context,
-                reporthook=self.add_progress,
-                cookies_path=cookies_path,
+                reporthook=self.add_progress
             )
 
             self.set_utime()
@@ -693,7 +692,7 @@ class URLTarget(object):
 
         return self.success
 
-    def urlretrieve(self, url: str, filename: str, context: ssl.SSLContext, reporthook=None, cookies_path=None):
+    def urlretrieve(self, url: str, filename: str, context: ssl.SSLContext, reporthook=None):
         """
         original source:
         https://github.com/python/cpython/blob/
@@ -775,4 +774,3 @@ class URLTarget(object):
             'success': self.success,
             'error': self.error,
         }
-
