@@ -14,6 +14,24 @@ class Course:
         self.overwrite_name_with = None
         self.create_directory_structure = True
 
+    @staticmethod
+    def build_categories(course_category: int, categories: [Category]) -> [Category]:
+        """
+        Build course tree category by all categories in Moodle
+        :param course_category: course category
+        :param categories: all categories
+        :return: course categories
+        """
+        course_categories = []
+
+        category = next((category for category
+                         in categories if category.id == course_category), None)
+
+        if category:
+            course_categories = Course.build_categories(category.parent_id, categories)
+
+        return course_categories + [category] if category else course_categories
+
     def __str__(self):
         message = 'Course ('
         message += 'id: %s' % self.id
