@@ -19,7 +19,7 @@ class PathTools:
         """
 
         if name is None:
-            return None
+            return ''
 
         # Moodle saves the title of a section in HTML-Format,
         # so we need to unescape the string
